Module common

Module common 

Common types for Cloudreve API v4

Structs

AggregatedItemError
A single item’s failure inside ApiResponse::aggregated_error.
ApiResponse
Generic API response wrapper

Constants

CODE_BATCH_OPERATION_NOT_FULLY_COMPLETED
Business code returned when a batch operation only partially succeeded.
CODE_LOCK_CONFLICT
Business code returned when a target file is locked by another session.