Common types for Cloudreve API v4
Structs
- Aggregated
Item Error - A single item’s failure inside
ApiResponse::aggregated_error. - ApiResponse
- Generic API response wrapper
Constants
- CODE_
BATCH_ OPERATION_ NOT_ FULLY_ COMPLETED - Business code returned when a batch operation only partially succeeded.
- CODE_
LOCK_ CONFLICT - Business code returned when a target file is locked by another session.